@@ -1,7 +1,7 @@
 package Progress::Any;
 
 our $DATE = '2018-03-17'; # DATE
-our $VERSION = '0.211'; # VERSION
+our $VERSION = '0.212'; # VERSION
 
 use 5.010001;
 use strict;
@@ -445,25 +445,31 @@ sub finish {
     $self->update(pos=>$self->{target}, state=>'finished', %args);
 }
 
-# - currently used letters: emnPpRrTt%
-# - currently used by Output::TermProgressBarColor: bB
-# - letters that can be used later: s (state)
+our $template_regex = qr{( # all=1
+                             %
+                             ( #width=2
+                                 -?\d+ )?
+                             ( #dot=3
+                                 \.?)
+                             ( #prec=4
+                                 \d+)?
+                             ( #conv=5
+                                 [A-Za-z%])
+                         )}x;
+
 sub fill_template {
-    my ($self, $template, %args) = @_;
+    my ($self, $template0, %args) = @_;
 
     # TODO: some caching so "%e%e" produces two identical numbers
 
-    state $re = qr{( # all=1
-                       %
-                       ( #width=2
-                           -?\d+ )?
-                       ( #dot=3
-                           \.?)
-                       ( #prec=4
-                           \d+)?
-                       ( #conv=5
-                           [emnPpRrTt%])
-                   )}x;
+    my ($template, $opts);
+    if (ref $template0 eq 'HASH') {
+        $opts = $template0;
+        $template = $opts->{template};
+    } else {
+        $template = $template0;
+        $opts = {};
+    }
 
     state $sub = sub {
         my %args = @_;
@@ -532,9 +538,29 @@ sub fill_template {
             }
             $width //= -(8 + 1 + 7);
         } else {
-            # return as-is
-            $fmt = '%s';
-            $data = $all;
+            if ($opts->{handle_unknown_conversion}) {
+                my @res = $opts->{handle_unknown_conversion}->(
+                    indicator => $p,
+                    args  => \%args,
+
+                    all   => $all,
+                    width => $width,
+                    dot   => $dot,
+                    conv  => $conv,
+                    prec  => $prec,
+                );
+                if (@res) {
+                    ($fmt, $data) = @res;
+                } else {
+                # return as-is
+                    $fmt = '%s';
+                    $data = $all;
+                }
+            } else {
+                # return as-is
+                $fmt = '%s';
+                $data = $all;
+            }
         }
 
         # sprintf format
@@ -544,9 +570,8 @@ sub fill_template {
 
         #say "D:fmt=$fmt";
         sprintf $fmt, $data;
-
     };
-    $template =~ s{$re}{$sub->(%args, indicator=>$self)}egox;
+    $template =~ s{$template_regex}{$sub->(%args, indicator=>$self)}egox;
 
     $template;
 }
@@ -566,7 +591,7 @@ Progress::Any - Record progress to any output
 
 =head1 VERSION
 
-This document describes version 0.211 of Progress::Any (from Perl distribution Progress-Any), released on 2018-03-17.
+This document describes version 0.212 of Progress::Any (from Perl distribution Progress-Any), released on 2018-03-17.
 
 =head1 SYNOPSIS
 
